@@ -6,33 +6,44 @@ knn.cv <- function(folds = NULL, nfolds = 10, stratified = FALSE, seed = FALSE,
   .Call(Rfast_k_nn_cv,folds, y, x, k, dist.type, type, method, freq.option, pred.ret, mem.eff)
 }
 
-generateFolds <- function(target, nfolds = 10, stratified = T, seed = F) {
+generateFolds <- function(target, nfolds = 10, stratified = TRUE, seed = FALSE) {
   names <- paste("Fold", 1:nfolds)
   runs <- sapply(names, function(x) NULL)
   if (seed) set.seed(1234)
-  
+
   if (!stratified) {
-    options(warn = -1)
-    mat <- matrix(sample(length(target)), ncol = nfolds)
-    for (i in 1:c(nfolds - 1)) runs[[i]] <- mat[, i]
-    names <- prod(dim(mat)) - length(target)
-    runs[[nfolds]] <- mat[1:c(nrow(mat) - names), nfolds]
+    oop <- options(warn = -1)
+    on.exit(options(oop))
+    ep <- sample(length(target))
+    nr <- round(length(target) / nfolds)
+    mat <- matrix(ep[1:(nr * nfolds)], ncol = nfolds)
+    for (i in 1:nfolds) runs[[i]] <- mat[, i]
+    rem <- ep[-c(1:(nr * nfolds))]
+    ela <- sample(nfolds, length(rem))
+    if (length(ela) > 0) {
+        for (i in 1:length(ela)) {
+            runs[[ela[i]]] <- c(runs[[i]], rem[i] )
+        }
+    }
   } else {
     labs <- unique(target)
     run <- list()
-    
     for (i in 1:length(labs)) {
       names <- which(target == labs[i])
-      run[[i]] <- sample(names) 
+      run[[i]] <- sample(names)
     }
-    
-    run <- unlist(run) 
-    
+    run <- unlist(run)
     for (i in 1:length(target)) {
       k <- i %% nfolds
       if (k == 0)  k <- nfolds
       runs[[k]] <- c(runs[[k]], run[i])
     }
-  } 
+  }
+  for (i in 1:nfolds)  {
+    if (any(is.na(runs[[i]]))) {
+        runs[[i]] <- runs[[i]][!is.na(runs[[i]])]
+    }
+  }
   runs
-}
\ No newline at end of file
+}
+
