@@ -147,7 +147,7 @@ BEGIN_RCPP
     traits::input_parameter< string >::type method(methodSEXP);
     traits::input_parameter< string >::type oper(operSEXP);
     traits::input_parameter< int >::type val(valSEXP);
-    __result = wrap(apply_condition(x,method,oper,val));
+    __result = apply_condition(x,method,oper,val);
     return __result;
 END_RCPP
 }
