@@ -17,13 +17,12 @@ double weighted_average_value(vec, a_node*, const int);
 double weighted_most_frequent_value(vec, a_node*, const int);
 double vmf_mle2(double, const int, const double, const double);
 colvec log1pColvec(colvec,int);
-double log1pColvecSum(colvec,int);
+double get_geom_lik(const double,const double, const double, double *, double *,const int);
 mat create_id_mat(int);
 double calc_f(vec, double, vec, double, double, int);
 vec gold_rat3(double, vec, vec, double, vec, const int, const double);
 double calc_multinom_ini(mat,vec);
 vec indexesOfNum(mat,int);
-double sumabsmat(mat,mat,int);
 double calcSumLog(mat,vec,int);
 mat colvec_mat_cbind(vec, mat);
 double calcDevRes(mat,vec,mat);
